# Interactive Sandbox

## Play with Colors

This sandbox is powered by [Pyodide](https://github.com/pyodide/pyodide). Preview, convert, interpolate, and explore!

<div id="playground-results">
<div class="color-command">
<div class="swatch-bar"></div>
<div class="highlight"><pre><code>Loading...</code></pre></div>
</div>
</div>
<textarea id="playground-inputs" spellcheck="false"># Insert your code here!
# Color objects, interpolation functions, and strings that look like colors
# will all be detected and previewed.

coloraide.__version__

Color('red')</textarea>

--8<-- "playground.txt"
